/** \file System.c
*
* Handles all that is associated with the MCU system
*
* $Name:  $
*/
/*******************************************************************************
* Copyright (c) 2006 Dynastream Innovations Inc.
* THE FOLLOWING EXAMPLE CODE IS INTENDED FOR LIMITED CIRCULATION ONLY.
* 
* Please forward all questions regarding this code to ANT Technical Support.
* 
* Dynastream Innovations Inc.
* 228 River Avenue
* Cochrane, Alberta, Canada
* T4C 2C1
* 
* (P) (403) 932-9292
* (F) (403) 932-6521
* (TF) 1-866-932-9292
* (E) support@thisisant.com
* 
* www.thisisant.com
*
*******************************************************************************/
#include "Config.h"

//------------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////
/// System_Init
///
/// This function is used initialize the clocks and watchdog parameters
///
/////////////////////////////////////////////////////////////////////////////
void System_Init(void)
{
	// Setup the Main System Clock
   SYSTEM_DCOCTL = MAX_MCLK_FREQ;            // Set DCO to highest frequency (max speed)

   SYSTEM_BCSCTL1 = SYSTEM_RSEL3 | 
                    SYSTEM_RSEL1 |           
                    SYSTEM_RSEL0;            // Set the internal RSEL for mid speed (MSP430F2xx)
   
   SYSTEM_BCSCTL1 &= ~SYSTEM_XTS;            // selecte low frequency mode for external clock source
   SYSTEM_BCSCTL1 |= SYSTEM_XT2OFF;          // do not use XT2

   SYSTEM_BCSCTL1 &= ~SYSTEM_DIVA0;          // set ACLK divider to 1
   SYSTEM_BCSCTL1 &= ~SYSTEM_DIVA1;          // set ACLK divider to 1
   
   SYSTEM_BCSCTL2 |= DIVS_3;                 // set SMCLK divider to 8
   
   SYSTEM_IE1  &= ~SYSTEM_OFIE;              // Disable Oscillator Fault Interrupt
   SYSTEM_IFG1 &= ~SYSTEM_OFIFG;             // Clear the Oscillator Fault Interrupt
	
   SYSTEM_IE1  &= ~SYSTEM_WATCHDOG_WDTIE;    // disable watchdog interrupt
   SYSTEM_IFG1 &= ~SYSTEM_WATCHDOG_WDTIFG;   // clear the watchdog interrupt flag
}

//------------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////
/// System_DisableWatchdog
///
/// This function disables the watchdog
///
/////////////////////////////////////////////////////////////////////////////
void System_DisableWatchdog(void)
{
   SYSTEM_WATCHDOG_TCTL = SYSTEM_WATCHDOG_PW | SYSTEM_WATCHDOG_HOLD;
}
