/** \file timer.c
*
* Implements functions related to timer A block of the MSP430
*
* $Name:  $
*/
/*******************************************************************************
* Copyright (c) 2006 Dynastream Innovations Inc.
* THE FOLLOWING EXAMPLE CODE IS INTENDED FOR LIMITED CIRCULATION ONLY.
* 
* Please forward all questions regarding this code to ANT Technical Support.
* 
* Dynastream Innovations Inc.
* 228 River Avenue
* Cochrane, Alberta, Canada
* T4C 2C1
* 
* (P) (403) 932-9292
* (F) (403) 932-6521
* (TF) 1-866-932-9292
* (E) support@thisisant.com
* 
* www.thisisant.com
*******************************************************************************/

#include "types.h"
#include "config.h"

#define DELAY_10us                 ((USHORT)1)           ///< Approximate number of counts for 10us delay

//------------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////
/// Timer_Init
///
/// This function is used initialize the timer
///
/////////////////////////////////////////////////////////////////////////////
void Timer_Init(void)
{
   TIMER_A_TACTL = TIMER_A_TASSEL |                      // set the clock source as SMCLK
                   TIMER_A_ID |                          // set the divider to 8
                   TACLR |                               // clear the timer
                   TIMER_A_MC;                           // continuous mode
	
   TIMER_A_TACTL &= ~TIMER_A_TAIE;                       // timer interrupt disabled
}

//------------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////
/// Timer_GetTime
///
/// This function is used to ensure that a stable value is read from the timer 
///
/// \return The 16-bit timer value is returned
/////////////////////////////////////////////////////////////////////////////
USHORT Timer_GetTime(void)
{
   USHORT usTime;

   // read a stable value from timer A register
   do
   {
      usTime = TIMER_A_TAR;
   }
   while (usTime != TIMER_A_TAR);

   return (usTime);                                      // return the current time
}

//------------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////
/// Timer_DelayTime
///
/// This function uses the timer to generate delays that are at least as long as
/// the specified duration
///
/// \param usTimein10us - The minimum amout of time to delay in 10 us units
/////////////////////////////////////////////////////////////////////////////
void Timer_DelayTime(USHORT usTimein10us)
{
   USHORT usTime;

   while (usTimein10us)                                 // wait for given time
   {
      usTime = Timer_GetTime();

      while(Timer_GetTime() - usTime < DELAY_10us);
      usTimein10us--;
   }
}
